package com.flyer.foster.controller;

import cn.dev33.satoken.annotation.SaCheckLogin;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.flyer.foster.dto.*;
import com.flyer.foster.entity.Garden;
import com.flyer.foster.service.IGardenService;
import com.flyer.util.R;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

/**
 * 果园
 *
 * @author flyer
 * @since 2024-05-09
 */
@RestController
@RequestMapping("/admin/garden")
public class GardenController {
    @Autowired
    private IGardenService iGardenService;

    /**
     * 果园列表-分页
     *
     * @param current 当前页
     * @param size    当前页显示条数
     * @return
     */
    @GetMapping("/list/{current}/{size}")
    public R getPageList(@PathVariable Integer current, @PathVariable Integer size, GardenQueryDTO queryDTO) {
        IPage<GardenRespDTO> page = new Page<>(current, size);
        return R.ok().result(iGardenService.getPageList(page, queryDTO));
    }

    /**
     * 根据id获取果园详情
     *
     * @return
     */
    @GetMapping("/{gardenId}")
    public R getById(@PathVariable Integer gardenId) {
        return R.ok().result(iGardenService.getById(gardenId));
    }

    /**
     * 新增果园
     *
     * @param addDTO
     * @return
     */
    @PostMapping("")
    public R addArea(@Valid @RequestBody GardenAddDTO addDTO) {
        return R.ok().result(iGardenService.addGarden(addDTO));
    }

    /**
     * 修改果园
     *
     * @param areaId
     * @param updateDTO
     * @return
     */
    @PutMapping("/{areaId}")
    public R updateArea(@PathVariable Integer areaId, @RequestBody GardenUpdateDTO updateDTO) {
        updateDTO.setId(areaId);
        return R.ok().result(iGardenService.updateGarden(updateDTO));
    }

    /**
     * 删除果园
     *
     * @return
     */
    @PostMapping("/delete")
    public R deleteGarden(@RequestBody List<Integer> idList) {
        return R.ok().result(iGardenService.deleteByIdList(idList));
    }
}
