package com.flyer.foster.controller;

import cn.dev33.satoken.annotation.SaCheckLogin;
import cn.dev33.satoken.annotation.SaIgnore;
import cn.dev33.satoken.stp.StpUtil;
import cn.hutool.core.bean.BeanUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.flyer.foster.dto.LoginDTO;
import com.flyer.foster.dto.UserAddDto;
import com.flyer.foster.dto.UserQueryDTO;
import com.flyer.foster.dto.UserRespDTO;
import com.flyer.foster.entity.User;
import com.flyer.foster.service.IUserService;
import com.flyer.util.R;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

/**
 * 用户
 *
 * @author flyer
 * @since 2024-05-06
 */
@Slf4j
@RestController
@RequestMapping("/admin/user")
public class UserController {
    @Autowired
    private IUserService iUserService;

    /**
     * 登录
     *
     * @param loginDto
     * @return
     */
    @PostMapping("/login")
    public R login(@RequestBody LoginDTO loginDto) {
        return R.ok().message("登录成功").result(iUserService.login(loginDto));
    }

    /**
     * 获取rsa公钥
     * @param username
     * @return
     */
    @GetMapping("/generate-key")
    public R getRsaKey(@RequestParam String username) {
        return R.ok().result(iUserService.getRsaKey(username));
    }

    /**
     * 根据登录信息获取用户信息
     *
     * @return
     */
    @GetMapping("")
    public R getUserInfo() {
        String username = StpUtil.getLoginId().toString();
        User user = iUserService.lambdaQuery().eq(User::getUsername, username).eq(User::getStatus, 1).one();
        UserRespDTO userRespDTO = new UserRespDTO();
        if (user != null) {
            BeanUtil.copyProperties(user, userRespDTO);
        }
        return R.ok().result(userRespDTO);
    }

    /**
     * 添加用户
     *
     * @param addDTO 用户添加对象
     * @return
     */
    @PostMapping("")
    public R addUser(@Valid @RequestBody UserAddDto addDTO) {
        return R.ok().result(iUserService.addUser(addDTO));
    }

    /**
     * 用户列表
     *
     * @return
     */
    @GetMapping("/list")
    public R getList(UserQueryDTO queryDTO) {
        return R.ok().result(iUserService.getList(queryDTO));
    }

    /**
     * 用户列表-分页
     *
     * @param current 当前页
     * @param size    当前页显示条数
     * @return
     */
    @GetMapping("/list/{current}/{size}")
    public R getPageList(@PathVariable Integer current, @PathVariable Integer size, UserQueryDTO queryDTO) {
        IPage<User> page = new Page<>(current, size);
        return R.ok().result(iUserService.getPageList(page, queryDTO));
    }

    /**
     * 删除用户
     *
     * @param idList 用户id集合
     * @return
     */
    @PostMapping("/delete")
    public R deleteUser(@RequestBody List<Integer> idList) {
        return R.ok().result(iUserService.removeByIdList(idList));
    }
}
